# Copyright 1999-2008 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: Robot Sevice Server $

inherit eutils

DESCRIPTION="Robot Device Server"
HOMEPAGE="http://playerstage.sourceforge.net"
SRC_URI="mirror://sourceforge/playerstage/${PN}-2.1.1.tar.bz2"
S="${WORKDIR}/${PN}-2.1.1"

KEYWORDS="~x86"
SLOT="0"
LICENSE="GPL-2 and LGPL-2.1, doc under FDL"
IUSE="X yarp gearbox roboop avahi howl gsl python opencv opengl imagemagick doc alsa gnome ieee1394 postgis sphinx2 festival usb gtk openssl glut boost fixedtones wifi v4l v4l2 gazebo java"

RESTRICT="mirror"

DEPEND="sys-devel/libtool
        X? ( >=dev-libs/glib-2 >=media-libs/freetype-2 x11-libs/pango dev-libs/atk >=x11-libs/gtk+-2 media-gfx/imagemagick )
        yarp? ( sci-misc/yarp dev-libs/ace )
        gearbox? ( dev-cpp/Ice sci-misc/gearbox )
        roboop? ( sci-misc/roboop )
	avahi? ( net-dns/avahi )        
	howl? ( >=net-misc/howl-0.9.6 )
	gsl? ( >=sci-libs/gsl-1.3 )
	python? ( >=dev-lang/python-2.2 dev-lang/swig dev-python/sip )
	opencv? ( media-libs/opencv )
	opengl? ( virtual/opengl )
	imagemagick? ( media-gfx/imagemagick )
        doc? ( app-doc/doxygen virtual/latex-base virtual/ghostscript app-text/psutils )
	alsa? ( media-libs/alsa-lib )
        gnome? ( >=gnome-base/libgnomecanvas-2.0 )
	ieee1394? ( sys-libs/libraw1394 media-libs/libdc1394 )
        postgis? ( dev-libs/libpqxx sci-libs/geos )
	sphinx2? ( app-accessibility/sphinx2 )
	festival? ( app-accessibility/festival )
        usb? ( dev-libs/libusb )
	gtk? ( x11-libs/gtk+ )
	openssl? ( dev-libs/openssl )
	glut? ( virtual/glut )
	boost? ( dev-libs/boost )
	fixedtones? ( >=sci-libs/fftw-2.1.5-r1 )
	wifi? ( net-wireless/wireless-tools )
	v4l? ( sys-kernel/gentoo-sources )
	v4l2? (sys-kernel/gentoo-sources dev-libs/klibc )
	gazebo? ( >=sci-misc/gazebo-0.5 )
	java? ( virtual/jdk dev-lang/python )
        sys-libs/zlib
        media-libs/jpeg
        dev-libs/boost
        dev-util/pkgconfig
	>=dev-util/cmake-2.6.0
	>=sys-apps/sed-4"

RDEPEND="${DEPEND}"

src_unpack() {
	unpack ${A}
	cd ${S}
	epatch ${FILESDIR}/player-2.2.0.patch
}

src_compile() {

# The following drivers will not be built:
# amtecm5
# fixedtones
# acoustics
# mixer
# artoolkitplus
# chatterbox
# garcia
# phidgetifk
# segwayrmp
# robotino
# sr3000
# isense
# phidgetRFID
# waveaudio
# rcore_xbridge
# phidgetAcc

elog " The following drivers are not supported by this ebuild: "
elog " amtecm5 "
elog " fixedtones "
elog " acoustics "
elog " mixer "
elog " artoolkitplus "
elog " chatterbox "
elog " garcia " 
elog " phidgetifk "
elog " segwayrmp "
elog " robotino "
elog " sr3000 "
elog " isense "
elog " phidgetRFID "
elog " waveaudio "
elog " rcore_xbridge "
elog " phidgetAcc "

	if ! use X;
        then
                elog " Lack of >=dev-libs/glib-2 or >=media-libs/freetype-2 or " 
		elog " x11-libs/pango or dev-libs/atk or >=x11-libs/gtk+-2 or "
		elog " media-gfx/imagemagick will disable same drivers and features"
        fi
	if ! use yarp;
        then
                elog " Lack of sci-misc/yarp dev-libs/ace will disable same drivers "
        fi
	if ! use gearbox;
        then
                elog " Lack of cpp-libs/Ice or sci-misc/gearbox will disable same drivers "
        fi
	if ! use roboop;
        then
                elog " Lack of sci-misc/roboop will disable same drivers "
        fi
	if ! use avahi && ! use howl;
        then
                elog " Lack of net-misc/avahi or >=net-misc/howl-0.9.6 will disable same drivers "
        fi
	if ! use gsl;
        then
                elog " Lack of >=sci-libs/gsl-1.3 will disable same drivers "
        fi
	if ! use python;
        then
                elog " Lack of >=dev-lang/python-2.2 or dev-lang/swig or dev-python/sip will disable same drivers "
        fi
	if ! use opencv;
        then
                elog " Lack of media-libs/opencv will disable same drivers "
        fi
	if ! use opengl;
        then
                elog " Lack of virtual/opengl will disable same drivers "
        fi
	if ! use imagemagick;
        then
                elog " Lack of media-gfx/imagemagick will disable same drivers "
        fi
	if ! use doc;
        then
                elog " Lack of app-doc/doxygen or virtual/latex-base or "
		elog " virtual/ghostscript or app-text/psutils will disable "
		elog " same of documentation "
        fi
	if ! use alsa;
        then
                elog " Lack of media-libs/alsa-lib will disable same drivers "
        fi
	if ! use gnome;
        then
                elog " Lack of >=gnome-base/libgnomecanvas-2.0 will disable same drivers and features"
        fi
	if ! use ieee1394;
        then
                elog " Lack of sys-libs/libraw1394 or media-libs/libdc1394 will disable same drivers "
        fi
	if ! use postgis;
        then
                elog " Lack of dev-libs/libpqxx or sci-libs/geos will disable same drivers "
        fi
	if ! use sphinx2;
        then
                elog " Lack of app-accessibility/sphinx2 will disable same drivers "
        fi
	if ! use festival;
        then
                elog " Lack of app-accessibility/festival will disable same drivers "
        fi
	if ! use usb;
        then
                elog " Lack of dev-libs/libusb will disable same drivers "
        fi
	if ! use gtk;
        then
                elog " Lack of x11-libs/gtk+ will disable same drivers and features"
        fi
	if ! use openssl;
        then
                elog " Lack of dev-libs/openssl will disable same drivers "
        fi
	if ! use glut;
        then
                elog " Lack of virtual/glut will disable same drivers "
        fi
	if ! use boost;
        then
                elog " Lack of dev-libs/boost will disable same drivers "
        fi
	if ! use fixedtones;
        then
                elog " Lack of >=sci-libs/fftw-2.1.5-r1 will disable same drivers "
        fi
	if ! use wifi;
        then
                elog " Lack of net-wireless/wireless-tools will disable same drivers "
        fi
	if ! use v4l;
        then
                elog " Lack of sys-kernel/gentoo-sources will disable same drivers "
        fi
	if ! use v4l2;
        then
                elog " Lack of sys-kernel/gentoo-sources or dev-libs/klibc will disable same drivers "
        fi
	if ! use gazebo;
        then
                elog " Lack of >=sci-misc/gazebo-0.5 will disable same drivers "
        fi
	if ! use java
        then
                elog " Lack of virtual/jdk or dev-lang/python will disable same drivers "
        fi

	cmake . || die "Error: cmake failed!"

	sed -i -e 's/BUILD_DOCUMENTATION\:BOOL=OFF/BUILD_DOCUMENTATION\:BOOL=ON/g' CMakeCache.txt || die "sed1"
	sed -i -e 's/CMAKE_INSTALL_PREFIX\:PATH\=\/usr\/local/CMAKE_INSTALL_PREFIX\:PATH=\/usr/g' CMakeCache.txt || die "sed2"
	sed -i -e 's/ENABLE_TCP_NODELAY\:BOOL=OFF/ENABLE_TCP_NODELAY\:BOOL=ON/g' CMakeCache.txt || die "sed3"
	sed -i -e 's/HAVE_PLAYERSD\:BOOL=OFF/HAVE_PLAYERSD\:BOOL=ON/g' CMakeCache.txt || die "sed4"
	sed -i -e 's/INCLUDE_RTKGUI\:BOOL=OFF/INCLUDE_RTKGUI\:BOOL=ON/g' CMakeCache.txt || die "sed5"
	sed -i -e 's/DEBUG_LEVEL\:STRING=NONE/DEBUG_LEVEL\:STRING=HIGH/g' CMakeCache.txt || die "sed6"

	cmake . || die "Error: cmake failed!"

	emake || die "Error: emake failed" 

       if use doc;
       then
          cd ${S}/doc
          emake doc || die "emake doc failed!"
          cd ${S}/doc/latex
          emake || die "latex emake failed!"
          cd ${S}
       fi
}

src_install() {
	einstall DESTDIR="${D}" || die " install failed"
	dodoc AUTHORS ChangeLog COPYING COPYING.lib README INSTALL TODO
	if use doc; then
         rm ${S}/doc/CMakeLists.txt
         dohtml  ${D}/usr/share/doc/${PF}/*.html
         dohtml  ${D}/usr/share/doc/${PF}/*.jpg
         dohtml  ${D}/usr/share/doc/${PF}/*.gif
         dohtml  ${D}/usr/share/doc/${PF}/*.png
         rm -rf  ${D}/usr/share/doc/${PF}/*.html
         rm -rf  ${D}/usr/share/doc/${PF}/*.jpg
         rm -rf  ${D}/usr/share/doc/${PF}/*.gif
         rm -rf  ${D}/usr/share/doc/${PF}/*.png
         insinto /usr/share/doc/${PF}/
         dodoc ${S}/doc/*.txt
         insinto  /usr/share/doc/${PF}/html/
         doins  ${S}/doc/*.html
         doins  ${S}/doc/*.php
         doins  -r ${S}/doc/images
         cd ${S}/doc/latex
         insinto /usr/share/doc/${PF}/
         doins *.pdf || die "latex errors!"
	fi
}
