# Copyright 1999-2008 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: Robot 2D Simulator $

inherit eutils

DESCRIPTION="Robot 2D Simulator"
HOMEPAGE="http://playerstage.sourceforge.net"
SRC_URI="mirror://sourceforge/playerstage/Stage-${PV}-Source.tar.bz2"

KEYWORDS="~x86"
SLOT="0"
LICENSE="GPL-2"
IUSE="doc"
RESTRICT="mirror"

DEPEND=">=x11-libs/gtk+-2.0
        >=sci-misc/player-2.1.0
	>=dev-util/cmake-2.6.0
	x11-libs/fltk
	dev-util/cppunit
	media-libs/libpng
        doc? ( app-doc/doxygen virtual/latex-base virtual/ghostscript app-text/psutils )"

RDEPEND="${DEPEND}"

S=${WORKDIR}/Stage-${PV}-Source

src_unpack() {
	unpack ${A}

	cd ${S}

	epatch ${FILESDIR}/stage-3.0.1.patch || die "epatch failed !"
}

src_compile() {
	cmake . || die "cmake failed !"

	sed -i -e 's/CMAKE_INSTALL_PREFIX\:PATH\=\/usr\/local/CMAKE_INSTALL_PREFIX\:PATH=\/usr/g' CMakeCache.txt || die "sed"

	cmake . || die "cmake failed !"

	emake || die "emake failed !"

	if use doc;
        then
	cd ${S}/docsrc
          emake doc || die "emake doc failed!"
          latex stage.tex || die "latex failed!"
	  dvipdf stage.dvi || die "dvipdf failed!"	
          cd ${S}
	fi
}

src_install() {
	einstall DESTDIR="${D}" || die "einstall failed!"
	dodoc AUTHORS.txt COPYING.txt DESCRIPTION.txt README.txt INSTALL.txt todo.txt RELEASE.txt
	dodoc ${S}/docsrc/*.txt
        insinto /usr/share/${PN}/worlds 
        doins  ${S}/worlds/*.cfg
        doins  ${S}/worlds/*.world
        doins  ${S}/worlds/*.inc
        doins  ${S}/worlds/*.sh
        insinto /usr/share/${PN}/worlds/bitmaps
        doins  ${S}/worlds/bitmaps/*.png
        insinto /usr/share/${PN}/worlds/wifi 
        doins  ${S}/worlds/wifi/*.cfg
        doins  ${S}/worlds/wifi/*.world
        doins  ${S}/worlds/wifi/*.inc
        insinto /usr/share/${PN}/worlds/benchmark 
        doins  ${S}/worlds/benchmark/*.cc
        doins  ${S}/worlds/benchmark/*.world
        doins  ${S}/worlds/benchmark/CMakeLists.txt
        insinto /usr/share/${PN}/examples/ctrl
        doins  ${S}/worlds/examples/ctrl/*.cc
        doins  ${S}/worlds/examples/ctrl/*.world
        doins  ${S}/worlds/examples/ctrl/CMakeLists.txt
        insinto /usr/share/${PN}/examples
        doins  -r ${S}/worlds/examples/libplayerc
        doins  -r ${S}/worlds/examples/libstage
 	if use doc; then
	 dohtml -r ${S}/docsrc/stage/*
	 insinto /usr/share/doc/${PF}/
	 doins ${S}/docsrc/stage.pdf
	fi
}
