# Copyright 1999-2008 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: Yet Another Robot Platform $

inherit eutils

DESCRIPTION="Yet Another Robot Platform"
HOMEPAGE="http://eris.liralab.it/yarp/specs/dox/user/html/index.html"
SRC_URI="http://downloads.sourceforge.net/yarp0/${P}.tar.gz"

RESTRICT="mirror"
LICENSE="GNU GPL 2"
SLOT="0"
KEYWORDS="~x86"
IUSE="X gtk doc"

DEPEND="X? ( x11-libs/gtk+ )
	gtk? ( x11-libs/gtk+ )
	doc? ( app-doc/doxygen virtual/latex-base virtual/ghostscript app-text/psutils )
	>=dev-util/cmake-2.6.0
	dev-libs/ace"

RDEPEND="${DEPEND}"

S="${WORKDIR}/${P}"

FRST_NBR=`echo "${PV}"|cut -d '.' -f 1`
SCND_NBR=`echo "${PV}"|cut -d '.' -f 2`

src_unpack() {
	unpack ${A}  || die "Unpacking ${A} failed!"
	cd ${S}
	
}

src_compile() {

	cmake . || die "Error: cmake failed!"

	sed -i -e 's/CMAKE_INSTALL_PREFIX\:PATH\=\/usr\/local/CMAKE_INSTALL_PREFIX\:PATH=\/usr/g' CMakeCache.txt || die "sed1"
	sed -i -e 's/CREATE_GUIS\:BOOL\=FALSE/CREATE_GUIS\:BOOL\=TRUE/g' CMakeCache.txt || die "sed2"
	sed -i -e 's/CREATE_SHARED_LIBRARY\:BOOL\=FALSE/CREATE_SHARED_LIBRARY\:BOOL\=TRUE/g' CMakeCache.txt || die "sed3"
	sed -i -e 's/CREATE_LIB_MATH\:BOOL\=FALSE/CREATE_LIB_MATH\:BOOL\=TRUE/g' CMakeCache.txt || die "sed"
	sed -i -e 's/CREATE_DEVICE_LIBRARY_MODULES\:BOOL\=FALSE/CREATE_DEVICE_LIBRARY_MODULES\:BOOL\=TRUE/g' CMakeCache.txt || die "sed4"

	cmake . || die "Error: cmake failed!"

	emake || die "Error: make failed!"

	if use doc; 
	then

	  ./scripts/make-manpages
	  ./scripts/update-doc

	  emake -f Makefile.man dox	

	  cd ${S}/src/libYARP_OS/doc/dev/latex
	  emake ps pdf ps_2on1 pdf_2on1

	  cd ${S}/src/libYARP_OS/doc/user/latex
	  emake ps pdf ps_2on1 pdf_2on1

	  cd ${S}/src/libYARP_sig/doc/dev/latex
	  emake ps pdf ps_2on1 pdf_2on1

	  cd ${S}/src/libYARP_sig/doc/user/latex
	  emake ps pdf ps_2on1 pdf_2on1

	  cd ${S}

	fi

}
src_install() {
	einstall DESTDIR="${D}"|| die "einstall failed"
	cd lib
	
	ln -fs libYARP_dev.so.${PV} libYARP_dev.so.${FRST_NBR}
	ln -fs libYARP_dev.so.${PV} libYARP_dev.so.${FRST_NBR}.${SCND_NBR}
	ln -fs libYARP_sig.so.${PV} libYARP_sig.so.${FRST_NBR}
	ln -fs libYARP_sig.so.${PV} libYARP_sig.so.${FRST_NBR}.${SCND_NBR}
	ln -fs libYARP_math.so.${PV} libYARP_math.so.${FRST_NBR}
	ln -fs libYARP_math.so.${PV} libYARP_math.so.${FRST_NBR}.${SCND_NBR}
	ln -fs libYARP_OS.so.${PV} libYARP_OS.so.${FRST_NBR}
	ln -fs libYARP_OS.so.${PV} libYARP_OS.so.${FRST_NBR}.${SCND_NBR}

	dolib.so libYARP_dev.so.${FRST_NBR}
	dolib.so libYARP_dev.so.${FRST_NBR}.${SCND_NBR}
	dolib.so libYARP_sig.so.${FRST_NBR}
	dolib.so libYARP_sig.so.${FRST_NBR}.${SCND_NBR}
	dolib.so libYARP_math.so.${FRST_NBR}
	dolib.so libYARP_math.so.${FRST_NBR}.${SCND_NBR}
	dolib.so libYARP_OS.so.${FRST_NBR}
	dolib.so libYARP_OS.so.${FRST_NBR}.${SCND_NBR}
	
	cd ${S}
	dodoc README REMOVED AUTHORS MIRRORING GPL.TXT NEWS QUICKSTART-DEBIAN.TXT
	if use doc; 
	then
	 doman doc/man/man/man1/*
	 dohtml doc/download.html 
	 dohtml doc/index.html
	 dohtml -r doc/images 
	 insinto /usr/share/doc/${P}
	 doins doc/yarpdoc.zip
	 rm -rf doc/dev/html/installdox
	 insinto /usr/share/doc/${P}/html/dev
	 doins -r doc/dev/html	
	 rm -rf doc/user/html/installdox
	 insinto /usr/share/doc/${P}/html/user
	 doins -r doc/user/html	
	 rm -rf doc/min/html/installdox
	 insinto /usr/share/doc/${P}/html/min
	 doins -r doc/min/html	
	 rm -rf doc/man/html/installdox
	 insinto /usr/share/doc/${P}/html/man
	 doins -r doc/man/html	
	
	 insinto /usr/share/doc/${P}
	 doins doc/spec/yarp-protocol-2-0.pdf

	 rm -rf  src/libYARP_OS/doc/dev/html/installdox
	 insinto /usr/share/doc/${P}/libYARP_OS/dev
	 doins -r src/libYARP_OS/doc/dev/html

	 rm -rf  src/libYARP_OS/doc/user/html/installdox
	 insinto /usr/share/doc/${P}/libYARP_OS/user
	 doins -r src/libYARP_OS/doc/user/html

	 # rm -rf  src/libYARP_sig/doc/dev/html/installdox
	 # insinto /usr/share/doc/${P}/libYARP_sig/dev
	 # doins -r src/libYARP_sig/doc/dev/html

	 rm -rf  src/libYARP_sig/doc/user/html/installdox
	 insinto /usr/share/doc/${P}/libYARP_sig/user
	 doins -r src/libYARP_sig/doc/user/html

	 cd ${S}/src/libYARP_OS/doc/dev/latex
	 insinto /usr/share/doc/${P}/libYARP_OS/dev
	 doins *.ps *.pdf

	 cd ${S}/src/libYARP_OS/doc/user/latex
	 insinto /usr/share/doc/${P}/libYARP_OS/user
	 doins *.ps *.pdf

	 # cd ${S}/src/libYARP_sig/doc/dev/latex
	 # insinto /usr/share/doc/${P}/libYARP_sig/dev
	 # doins *.ps *.pdf

	 cd ${S}/src/libYARP_sig/doc/user/latex
	 insinto /usr/share/doc/${P}/libYARP_sig/user
	 doins *.ps *.pdf
	
	fi
}
